/*	$Id: att.c,v 1.13 2014/11/28 18:57:31 schwarze Exp $ */
/*
 * Copyright (c) 2009 Kristaps Dzonsons <kristaps@bsd.lv>
 *
 * Permission to use, copy, modify, and distribute this software for any
 * purpose with or without fee is hereby granted, provided that the above
 * copyright notice and this permission notice appear in all copies.
 *
 * THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
 * WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
 * ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
 * ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 * OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */
#include "config.h"

#include <sys/types.h>
#include <string.h>

#include "mdoc.h"
#include "libmdoc.h"

#define LINE(x, y) \
	if (0 == strcmp(p, x)) return(y)


const char *
mdoc_a2att(const char *p)
{

	LINE("v1",	"Version\\~1 AT&T UNIX");
	LINE("v2",	"Version\\~2 AT&T UNIX");
	LINE("v3",	"Version\\~3 AT&T UNIX");
	LINE("v4",	"Version\\~4 AT&T UNIX");
	LINE("v5",	"Version\\~5 AT&T UNIX");
	LINE("v6",	"Version\\~6 AT&T UNIX");
	LINE("v7",	"Version\\~7 AT&T UNIX");
	LINE("32v",	"Version\\~32V AT&T UNIX");
	LINE("III",	"AT&T System\\~III UNIX");
	LINE("V",	"AT&T System\\~V UNIX");
	LINE("V.1",	"AT&T System\\~V Release\\~1 UNIX");
	LINE("V.2",	"AT&T System\\~V Release\\~2 UNIX");
	LINE("V.3",	"AT&T System\\~V Release\\~3 UNIX");
	LINE("V.4",	"AT&T System\\~V Release\\~4 UNIX");

	return(NULL);
}
